==> 3.5.12-core.tar: kdesdk/kbabel/kbabel/errorlistview.cpp <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 1999-2000 by Matthias Kiefer
                            <matthias.kiefer@gmx.de>
		2002-2004  by Stanislav Visnovsky
			    <visnovsky@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the Qt library by Trolltech AS, Norway (or with modified versions
  of Qt that use the same license as Qt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  Qt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.

**************************************************************************** */

#include "errorlistview.h"

#include <tqlayout.h>
#include <tqtextview.h>
#include <tqwhatsthis.h>

#include <kcursor.h>
#include <klocale.h>

#include "resources.h"
#include "kbcatalog.h"

using namespace KBabel;

ErrorListView::ErrorListView(KBCatalog* catalog,TQWidget *parent, Project::Ptr project)
    : KBCatalogView(catalog,parent,project)
{
	TQVBoxLayout* layout = new TQVBoxLayout( this );
	layout->setResizeMode( TQLayout::Minimum );

	_textview = new TQTextView (this);
	KCursor::setAutoHideCursor(_textview->viewport(),true);
	_textview->setReadOnly(true);

	layout->addWidget(_textview);

	TQWhatsThis::add(this, i18n( "<qt><p><b>Error List</b></p>"
			"<p>This window shows the list of errors found by validator tools "
			"so you can know why the current message has been marked with an "
			"error.</p></qt>" ) );
}

void ErrorListView::updateView()
{
	if( _catalog->numberOfEntries() == 0 )
		return;

	_textview->setText( _catalog->itemStatus( _currentIndex ).join( "\n---\n" ) );
}

#include "errorlistview.moc"

==> 3.5.13-core.tar: kdesdk/kbabel/kbabel/errorlistview.cpp <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 1999-2000 by Matthias Kiefer
                            <matthias.kiefer@gmx.de>
		2002-2004  by Stanislav Visnovsky
			    <visnovsky@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the TQt library by Trolltech AS, Norway (or with modified versions
  of TQt that use the same license as TQt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  TQt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.

**************************************************************************** */

#include "errorlistview.h"

#include <tqlayout.h>
#include <tqtextview.h>
#include <tqwhatsthis.h>

#include <kcursor.h>
#include <klocale.h>

#include "resources.h"
#include "kbcatalog.h"

using namespace KBabel;

ErrorListView::ErrorListView(KBCatalog* catalog,TQWidget *parent, Project::Ptr project)
    : KBCatalogView(catalog,parent,project)
{
	TQVBoxLayout* tqlayout = new TQVBoxLayout( this );
	tqlayout->setResizeMode( TQLayout::Minimum );

	_textview = new TQTextView (this);
	KCursor::setAutoHideCursor(_textview->viewport(),true);
	_textview->setReadOnly(true);

	tqlayout->addWidget(_textview);

	TQWhatsThis::add(this, i18n( "<qt><p><b>Error List</b></p>"
			"<p>This window shows the list of errors found by validator tools "
			"so you can know why the current message has been marked with an "
			"error.</p></qt>" ) );
}

void ErrorListView::updateView()
{
	if( _catalog->numberOfEntries() == 0 )
		return;

	_textview->setText( _catalog->itemtqStatus( _currentIndex ).join( "\n---\n" ) );
}

#include "errorlistview.moc"
